# TODO
- Make a recipe (with possible variants, e.g. color of lit)
- A process is then a concrete 'recipe'/variant 
- Agents as operators and robots? - or humans, robots, machines?
- Figure out how to map between process+agents and environments.
- 